@@ -14,20 +14,18 @@ class KeenApi(object):
     # the default version of the Keen API
     api_version = "3.0"
 
-    def __init__(self, project_id, api_key, base_url=None,
+    def __init__(self, project_token, base_url=None,
                  api_version=None):
         """ Initializes a KeenApi object
 
-        :param project_id: the Keen project ID
-        :param api_key: the Keen API key
+        :param project_token: the Keen project token
         :param base_url: optional, set this to override where API requests
         are sent
         :param api_version: string, optional, set this to override what API
         version is used
         """
         super(KeenApi, self).__init__()
-        self.project_id = project_id
-        self.api_key = api_key
+        self.project_token = project_token
         if base_url:
             self.base_url = base_url
         if api_version:
@@ -39,10 +37,9 @@ class KeenApi(object):
         :param event: an Event to upload
         """
         url = "{}/{}/projects/{}/events/{}".format(self.base_url, self.api_version,
-                                            self.project_id,
+                                            self.project_token,
                                             event.collection_name)
-        headers = {"Authorization": self.api_key,
-                   "Content-Type": "application/json"}
+        headers = {"Content-Type": "application/json"}
         payload = event.to_json()
         response = requests.post(url, data=payload, headers=headers)
         if response.status_code != 201:
